import dotenv


def fetch_to_env(override: bool = True) -> None:
    """Searches for an .env file recursively up the tree from cwd to root.

    The env var should contain standard VARIABLE="VALUE" lines. Lines prefixed
    with a # are ignored as comments. White space is ignored.

    The contents of the env file will be loaded in to os.environ
    """
    dotenv.load_dotenv(dotenv.find_dotenv(usecwd=True), override=override)



import dataclasses
import os
from typing import Any, Callable

sentinel = object()


def env(key: str, convert: Callable = str, **kwargs) -> dataclasses.Field:
    """
    A factory around `dataclasses.field` that can be used to load or default
    an envvar. If you wish to load from an external source, do that first and
    inject it's values into os.environ before instantiating your
    config/settings class.

    Args:
        key: in the format of either KEY or KEY:DEFAULT
        convert: a function that accepts a string and returns a different type
        kwargs: any remaining kwargs for `dataclasses.field`

    Returns:
        dataclasses.field

    Raises:
        KeyError: in the event an envvar isn't found and doesn't have a default
    """
    key, partition, default = key.partition(":")

    # handle `KEY:` for default of empty string as partition returns empty string when partition is missing.
    if partition == "":
        default = sentinel

    def default_factory(key: str = key, default: Any = default, convert: Callable = convert) -> None:  # noqa: ANN401
        value = os.environ.get(key)
        if value is None:
            if default != sentinel:
                value = default
            else:
                raise KeyError(key)

        try:
            return convert(value)
        except ValueError as e:
            msg = f"{key} {str(e)}"
            raise ValueError(msg) from e

    return dataclasses.field(default_factory=default_factory, **kwargs)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['app_confetti', 'app_confetti.fetch']

package_data = \
{'': ['*']}

install_requires = \
['python-dotenv>=0.15.0,<0.16.0']

extras_require = \
{'aws': ['boto3>=1.14.49,<2.0.0', 'ec2-metadata>=2.2.0,<3.0.0']}

entry_points = \
{'console_scripts': ['changelog-gen = changelog_gen.cli.command:gen',
                     'changelog-init = changelog_gen.cli.command:init']}

setup_kwargs = {
    'name': 'app-confetti',
    'version': '0.2.0',
    'description': 'Environment application configuration',
    'long_description': '# Configuration Fetcher v0.2.0\n\nCommon code for interacting with dev environs, deployed environs with ENV vars\nor for deployed AWS (optional extra) environs.\n\n## Config class\n\n```python\n    from app_confetti import util\n\n    @dataclasses.dataclass(frozen=True)\n    class Config:\n        required_key: str = util.env("REQUIRED_KEY")\n        logging_level: str = util.env("LOGGING_LEVEL:INFO")\n        sentry_dsn: int = util.env("SENTRY_DSN:__NONE__")\n        debug: bool = util.env("DEBUG:__FALSE__")\n\n        @property\n        def logging_config(self):\n            return {\n                "version": 1,\n                "disable_existing_loggers": False,\n                "formatters": {\n                    "default": {\n                        "format": "[%(asctime)s][%(name)s][%(levelname)s]: %(message)s",\n                        "datefmt": "%Y-%m-%d %H:%M:%S",\n                    },\n                },\n                "handlers": {\n                    "default": {\n                        "class": "logging.StreamHandler",\n                        "level": self.logging_level,\n                        "formatter": "default",\n                    },\n                    "sentry": {\n                        "level": "ERROR",\n                        "class": "raven.handlers.logging.SentryHandler",\n                        "dsn": self.sentry_dsn,\n                    },\n                },\n                "loggers": {\n                    "": {\n                        "handlers": ["default", "sentry"],\n                        "level": self.logging_level,\n                        "propagate": True,\n                    },\n                    "raven": {\n                        "handlers": ["default"],\n                        "level": "WARNING",\n                        "propagate": True,\n                    },\n                },\n            }\n```\n',
    'author': 'Daniel Edgecombe',
    'author_email': 'edgy.edgemond@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/EdgyEdgemond/app-confetti/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



import ast
import os
from typing import Any

import boto3
from botocore.exceptions import ClientError
from ec2_metadata import ec2_metadata


def str_to_literal(val: str) -> Any:  # noqa: ANN401
    """
    Construct an object literal from a str, but leave other types untouched
    """
    if isinstance(val, str):
        try:
            return ast.literal_eval(val)
        except ValueError:
            pass
    return val


def get_region() -> str:
    return ec2_metadata.region


def fetch_to_env(secret_name: str = "settings") -> None:  # nosec: B107
    """
    If you need more information about configurations or implementing the sample code, visit the AWS docs:
    https://aws.amazon.com/developers/getting-started/python/
    """

    region_name = get_region()
    instance_id = ec2_metadata.instance_id

    session = boto3.session.Session()

    # Create an EC2 client
    client = session.client(
        service_name="ec2",
        region_name=region_name,
    )

    response = client.describe_instances(InstanceIds=[instance_id])
    tags = response["Reservations"][0]["Instances"][0]["Tags"]
    tag_data = {tag["Key"]: tag["Value"] for tag in tags}

    # Create a Secrets Manager client
    client = session.client(
        service_name="secretsmanager",
        region_name=region_name,
    )

    # In this sample we only handle the specific exceptions for the "GetSecretValue" API.
    # See https://docs.aws.amazon.com/secretsmanager/latest/apireference/API_GetSecretValue.html
    # We rethrow the exception by default.

    secrets = {}
    try:
        get_secret_value_response = client.get_secret_value(
            SecretId=secret_name,
        )
    except ClientError:
        """
        e.response["Error"]["Code"] == "DecryptionFailureException":
            # Secrets Manager can"t decrypt the protected secret text using the provided KMS key.
            # Deal with the exception here, and/or rethrow at your discretion.
        e.response["Error"]["Code"] == "InternalServiceErrorException":
            # An error occurred on the server side.
            # Deal with the exception here, and/or rethrow at your discretion.
        e.response["Error"]["Code"] == "InvalidParameterException":
            # You provided an invalid value for a parameter.
            # Deal with the exception here, and/or rethrow at your discretion.
        e.response["Error"]["Code"] == "InvalidRequestException":
            # You provided a parameter value that is not valid for the current state of the resource.
            # Deal with the exception here, and/or rethrow at your discretion.
        e.response["Error"]["Code"] == "ResourceNotFoundException":
            # We can"t find the resource that you asked for.
            # Deal with the exception here, and/or rethrow at your discretion.
        """
        raise
    else:
        # Decrypts secret using the associated KMS CMK.
        secret = get_secret_value_response["SecretString"]
        secrets = str_to_literal(secret)

    secrets.update(tag_data)
    os.environ.update({k: str(v) for k, v in secrets.items()})
